.. highlight:: shell

============
Installation
============


Stable release
--------------

To install AskAnna CLI, run this command in your terminal:

.. code-block:: console

   $ pip install askanna


From sources
------------

The sources for AskAnna CLI can be downloaded from the `Gitlab repo`_.

Assuming you have access to the repo:

.. code-block:: console

   $ git clone git@gitlab.askanna.io:askanna/askanna-cli.git

Once you have a copy of the source, you can install it with:

.. code-block:: console

   $ python setup.py install
